@@ -19,6 +19,7 @@ from .conftest import Reader
         "crossing-latitude",
         "extra-crossing",
         "issues-81",
+        "issues-171",
         "latitude-band",
         "north-pole",
         "one-hole",
@@ -112,7 +113,7 @@ def test_dont_segment_antimeridian_overlap(minx: float, maxx: float) -> None:
     assert fixed.geom_type == "Polygon"
 
 
-@pytest.mark.parametrize("name", ("cw-only", "cw-split"))
+@pytest.mark.parametrize("name", ("cw-only", "cw-split", "issues-174"))
 @pytest.mark.parametrize(
     "subdirectory,great_circle",
     [("flat", False), ("spherical", True)],
